@@ -22,9 +22,6 @@
 #                                                                              #
 ################################################################################
 
-import datetime
-import json
-
 import github.GithubObject
 import github.ProjectColumn
 
