@@ -48,6 +48,8 @@ import github.Repository
 import github.NamedUser
 import github.Organization
 
+from . import Consts
+
 
 class Team(github.GithubObject.CompletableGithubObject):
     """
@@ -291,6 +293,21 @@ class Team(github.GithubObject.CompletableGithubObject):
             None
         )
 
+    def invitations(self):
+        """
+        :calls: `GET /teams/:id/invitations <https://developer.github.com/v3/teams/members>`_
+        :rtype: :class:`github.PaginatedList.PaginatedList` of :class:`github.NamedUser.NamedUser`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.NamedUser.NamedUser,
+            self._requester,
+            self.url + "/invitations",
+            None,
+            headers={
+                "Accept": Consts.mediaTypeOrganizationInvitationPreview
+            }
+        )
+
     def has_in_members(self, member):
         """
         :calls: `GET /teams/:id/members/:user <http://developer.github.com/v3/orgs/teams>`_
